@@ -8,20 +8,17 @@ sys.path.append(cwd)
 import data
 
 def start():
-    try:
-        key = zip(data.questions, data.answers)
-    except AttributeError:
-        print "You need to create a data.py answer key first!"
-        sys.exit(0)
+
+    key = zip(data.questions, data.answers)
+
     shuffle(key)
-    
-    print "="*72
     for entry in key:
         question = entry[0]
         answer = entry[1]
         correct = False
  
-        print "Question:\t%s" % question
+
+        print question
         reply = raw_input("> ")
         
         if isinstance(answer, tuple):
@@ -44,13 +41,13 @@ def start():
                 for each in answer:
                     temp.append(each)
                 
-                print "\tany of the following:"
+                print "\tAny of the following:"
                 print "\t",' | '.join(temp)
                 
             if isinstance(answer, str):
                 print answer
         print "="*72
-    print "\n\nYou have gone through each entry in the list!"
+    raw_input("\nYou have gone through each entry in the list!\nHit ENTER to break back to the main menu\n\n")
 
 
 if __name__ == "__main__":    
